---
slug: /conditional-processing-and-out-or-inout-parameters
---

# Exception handling and OUT/INOUT parameters

In some scenarios, stored programs do not return the modified values of `OUT` and `INOUT` parameters to the caller.

If a stored procedure exits due to an unhandled exception, its `OUT` and `INOUT` parameters do not return modified values to the caller.

If the exception handler contains a `RESIGNAL` statement in a `CONTINUE` or `EXIT` handler, executing `RESIGNAL` pops the diagnostic area's stack and emits the exception signal (the information that existed before entering the handler). If the exception is an error, the `OUT` and `INOUT` parameters do not return modified values to the caller.